@@ -77,7 +77,9 @@ except ImportError:
 from lal import LIGOTimeGPS
 from lal.utils import CacheEntry
 
-from . import (git_version, segments)
+from ligo import segments
+
+from . import git_version
 from .lal import Cache
 
 Cache.entry_class = CacheEntry
@@ -233,7 +235,7 @@ class GWDataFindHTTPConnection(http_client.HTTPConnection):
         Use gpsstart and gpsend to restrict the returned times to
         this semiopen interval.
 
-        @returns: L{segmentlist<glue.segments.segmentlist>}
+        @returns: L{segmentlist<ligo.segments.segmentlist>}
 
         @param site:
             single-character name of site to match
@@ -259,7 +261,7 @@ class GWDataFindHTTPConnection(http_client.HTTPConnection):
         segmentlist = self.get_json(url)
         return segments.segmentlist(map(segments.segment, segmentlist))
 
-    def find_frame(self, framefile, urltype=None, on_missing="warn"):
+    def find_frame(self, framefile, urltype='file', on_missing="warn"):
         """Query the LDR host for a single framefile
 
         @returns: L{Cache<glue.lal.Cache>}
@@ -267,7 +269,8 @@ class GWDataFindHTTPConnection(http_client.HTTPConnection):
         @param frametype:
             name of frametype to match
         @param urltype:
-            file scheme to search for (e.g. 'file')
+            file scheme to search for, one of 'file', 'gsiftp', or
+            `None`, default: 'file'
         @param on_missing:
             what to do when the requested frame isn't found, one of:
                 - C{'warn'} (default): print a warning,
@@ -305,7 +308,7 @@ class GWDataFindHTTPConnection(http_client.HTTPConnection):
              x in urllist] if not urltype or e.scheme == urltype)
         return cache
 
-    def find_latest(self, site, frametype, urltype=None, on_missing="warn"):
+    def find_latest(self, site, frametype, urltype='file', on_missing="warn"):
         """Query for the most recent framefile of a given type.
 
         @param  site:
@@ -313,7 +316,8 @@ class GWDataFindHTTPConnection(http_client.HTTPConnection):
         @param frametype:
             name of frametype to match
         @param urltype:
-            file scheme to search for (e.g. 'file')
+            file scheme to search for, one of 'file', 'gsiftp', or
+            `None`, default: 'file'
         @param on_missing:
             what to do when the requested frame isn't found, one of:
                 - C{'warn'} (default): print a warning,
@@ -351,7 +355,7 @@ class GWDataFindHTTPConnection(http_client.HTTPConnection):
             x in urllist])
 
     def find_frame_urls(self, site, frametype, gpsstart, gpsend,
-                        match=None, urltype=None, on_gaps="warn"):
+                        match=None, urltype='file', on_gaps="warn"):
         """Find the framefiles for the given type in the [start, end) interval
         frame
 
@@ -366,7 +370,8 @@ class GWDataFindHTTPConnection(http_client.HTTPConnection):
         @param match:
             regular expression to match against
         @param urltype:
-            file scheme to search for (e.g. 'file')
+            file scheme to search for, one of 'file', 'gsiftp', or
+            `None`, default: 'file'
         @param on_gaps:
             what to do when the requested frame isn't found, one of:
                 - C{'warn'} (default): print a warning,
