@@ -48,8 +48,9 @@ try:  # python < 3
 except NameError:  # python >= 3
     long = int
 
+from ligo import segments
+
 from glue import git_version
-from glue import segments
 
 
 __author__ = "Kipp Cannon <kipp.cannon@ligo.org>"
