@@ -45,9 +45,10 @@ from xml.sax.xmlreader import AttributesImpl
 import warnings
 
 
+from ligo import segments
+
 from glue import git_version
 from glue import offsetvector
-from glue import segments
 from . import ilwd
 from . import ligolw
 from . import table
@@ -760,7 +761,13 @@ class DBTable(table.Table):
 
 	def __iter__(self):
 		cursor = self.connection.cursor()
-		cursor.execute("SELECT * FROM %s" % self.Name)
+		cursor.execute("SELECT * FROM %s ORDER BY rowid ASC" % self.Name)
+		for values in cursor:
+			yield self.row_from_cols(values)
+
+	def __reversed__(self):
+		cursor = self.connection.cursor()
+		cursor.execute("SELECT * FROM %s ORDER BY rowid DESC" % self.Name)
 		for values in cursor:
 			yield self.row_from_cols(values)
 
