@@ -31,10 +31,10 @@ Ask Kipp to document this!
 
 import itertools
 
+from ligo import segments
 
 from glue import git_version
 from glue import iterutils
-from glue import segments
 from glue import segmentsUtils
 from .. import ligolw
 from .. import lsctables
@@ -74,7 +74,7 @@ class LigolwSegmentList(object):
 
 	Example:
 
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> segs = segmentlist([segment(0, 10), segment(20, 30)])
 	>>> validity = segmentlist([segment(0, 10), segment(25, 100)])
 	>>> x = LigolwSegmentList(active = segs, valid = validity, instruments = set(("H1",)), name = "test")
@@ -105,7 +105,7 @@ class LigolwSegmentList(object):
 
 	Example:
 
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> segs = segmentlist([segment(0, 10), segment(20, 30)])
 	>>> validity = segmentlist([segment(0, 35)])
 	>>> x = LigolwSegmentList(active = segs, valid = validity, instruments = set(("H1",)), name = "test")
@@ -348,7 +348,7 @@ class LigolwSegments(set):
 	Example:
 
 	>>> import sys
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> from lal import LIGOTimeGPS
 	>>> from glue.ligolw import ligolw, lsctables
 	>>> xmldoc = ligolw.Document()
