@@ -20,7 +20,7 @@ import sys
 import os
 import re
 
-from glue.segments import segment, segmentlist
+from ligo.segments import segment, segmentlist
 from glue.ligolw import lsctables
 from glue.ligolw import table
 from glue.segmentdb import query_engine
