@@ -33,10 +33,11 @@ objects.
 import re
 
 
+from ligo import segments
+
 from glue import git_version
 from glue.lal import CacheEntry
 from .lal import LIGOTimeGPS
-from glue import segments
 from six.moves import range
 
 
@@ -280,7 +281,7 @@ def to_range_strings(seglist):
 
 	Example:
 
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> segs = segmentlist([segment(0, 10), segment(35, 35), segment(100, infinity())])
 	>>> ",".join(to_range_strings(segs))
 	'0:10,35,100:'
@@ -318,7 +319,7 @@ def segmentlistdict_to_short_string(seglists):
 
 	Example:
 
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> segs = segmentlistdict({"H1": segmentlist([segment(0, 10), segment(35, 35), segment(100, infinity())]), "L1": segmentlist([segment(5, 15), segment(45, 60)])})
 	>>> segmentlistdict_to_short_string(segs)
 	'H1=0:10,35,100:/L1=5:15,45:60'
@@ -405,7 +406,7 @@ def S2playground(extent):
 
 	Example:
 
-	>>> from glue import segments
+	>>> from ligo import segments
 	>>> S2playground(segments.segment(874000000, 874010000))
 	[segment(874000013, 874000613), segment(874006383, 874006983)]
 	"""
@@ -426,7 +427,7 @@ def segmentlist_range(start, stop, period):
 
 	Example:
 
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> segmentlist(segmentlist_range(0, 15, 5))
 	[segment(0, 5), segment(5, 10), segment(10, 15)]
 	>>> segmentlist(segmentlist_range('', 'xxx', 'x'))
@@ -466,7 +467,7 @@ def Fold(seglist1, seglist2):
 
 	Example:
 
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> x = segmentlist([segment(0, 13), segment(14, 20), segment(22, 36)])
 	>>> for y in Fold(x, segmentlist_range(0, 48, 24)): print y
 	...
@@ -485,7 +486,7 @@ def vote(seglists, n):
 
 	Example:
 
-	>>> from glue.segments import *
+	>>> from ligo.segments import *
 	>>> w = segmentlist([segment(0, 15)])
 	>>> x = segmentlist([segment(5, 20)])
 	>>> y = segmentlist([segment(10, 25)])
